/********************************************************
 An include file for applications using S615
 Copyright (C) Sensoray Co., Inc., 2002
 *******************************************************/
#ifndef __615__h
#define __615__h


#define SYS_BUFFERS   4 //number of buffers to create
#define SYS_BOARDS 4
#define	SYS_NOFREEBUFFERS	SYS_BUFFERS	//no free buffers left

#define S615MAGIC 0xDB

#define S615Start        _IO (S615MAGIC, 0x01)
#define S615Stop         _IO (S615MAGIC, 0x02)
#define S615FreeBuffer  _IOW (S615MAGIC, 0x03, int)


typedef unsigned char BYTE;
typedef unsigned short WORD;
typedef unsigned long DWORD;
typedef short SHORT;
typedef long LONG;
typedef void* PVOID;
typedef BYTE UCHAR;
typedef WORD USHORT;
typedef DWORD ULONG;
typedef char CHAR;
typedef PVOID HANDLE;
typedef BYTE BOOLEAN;
typedef void VOID;
typedef int BOOL;
typedef DWORD ECODE;

#define TRUE 1
#define FALSE 0

//MODE constants
#define	FORMAT_NTSC					0
#define	FORMAT_PAL					1

#define	FLIP_OFF					0
#define FLIP_ON						1	//image is stored upside down 

#define COLOR_MONO					0	//momochrome bitmap
#define	COLOR_YCRCB					1	//color bitmap (YCrCb format, 2 bytes/pixel, CbYCrY)
#define	COLOR_RGB					2	//color bitmap (RGB format, 3 bytes/pixel)
#define	COLOR_YCRCB_BS				4	//color bitmap (YCrCb format, 2 bytes/pixel, YCbYCr)

#define BMP_SIZE_LRG				0	//large bitmap (256x192)
#define	BMP_SIZE_SML				1	//small bitmap (128x96)

#define	JPG_SIZE_FULL				0	//full size JPEG (704x480 or 704x576)
#define	JPG_SIZE_HALF				1	//half size JPEG (352x240 or 352x288)
#define	JPG_SIZE_FULL_C				2	//full size clipped JPEG (640x480, not valid for PAL)
#define	JPG_SIZE_HALF_C				3	//half size clipped JPEG (320x240, not valid for PAL)

#define CAP8X8						0	//8 chars by 8 lines caption
#define CAP16X4						1	//16 chars by 4 lines caption
#define	CAP32X2						2	//32 chars by 2 lines caption

#define	CP_UL						0	//caption window in upper left corner
#define	CP_UR						1	//caption window in upper right corner
#define	CP_LL						2	//caption window in lower left corner
#define	CP_LR						3	//caption window in lower right corner

#define	CF_SMALL					0	//small caption font size
#define	CF_LARGE					1	//large caption font size

#define	COMPFACTOR_MIN				0xa0	//minimum compression factor

#define XPS_INIT					0x01020304	//chan0-xpchan1, chan1-xpchan2, chan2-xpchan3, chan3-xpchan4

#define DEF_MODE   {FORMAT_NTSC, FLIP_ON, COLOR_YCRCB_BS, BMP_SIZE_LRG, JPG_SIZE_FULL, CAP16X4, CP_UL, CF_LARGE, COMPFACTOR_MIN, XPS_INIT}

#define		BMPLINES_NTSC_SML	96	//lines per field, NTSC
#define		BMPLINES_NTSC_LRG	BMPLINES_NTSC_SML * 2	//lines per field, NTSC
#define		BMPPIXELS_NTSC_SML	128	//pixels per line~~
#define		BMPPIXELS_NTSC_LRG	BMPPIXELS_NTSC_SML * 2	//pixels per line

#define		BMPLINES_PAL_SML	96	//lines per field, PAL
#define		BMPLINES_PAL_LRG	BMPLINES_PAL_SML * 2	//lines per field, PAL
#define		BMPPIXELS_PAL_SML	128	//pixels per line~~
#define		BMPPIXELS_PAL_LRG	BMPPIXELS_PAL_SML * 2	//pixels per line

#define		BYTESPERPIX_MONO	1	//bytes per pixel, monochrome
#define		BYTESPERPIX_YUV		2
#define		BYTESPERPIX_RGB		3	//~~bytes per pixel, color

#define		BMPLINES_PAL		272	//lines per field, PAL

#define		SYS_BMPSIZE		BMPPIXELS_NTSC_LRG * BMPLINES_NTSC_LRG * BYTESPERPIX_RGB
#define         SYS_JPGSIZE     	0x32000	//max jpeg size, 200K



//Error Codes
#define		ERR_MEM_ALLOC			4	//memory allocation error
#define		ERR_I2CINIT_BUSY		6	//internal I2C bus initialization error
#define		ERR_I2CINIT_ERR			7	//internal I2C bus initialization error
#define		ERR_TIMEOUT			8	//internal access timeout
#define		ERR_I2C				13	//internal I2C bus error
#define		ERR_I2CTO			14	//internal I2C timeout
#define		ERR_XPTO			16	//internal crosspoint switch timeout
#define		ERR_SRAM			17	//error loading SRAM
#define		ERR_ILLEGAL_MODE		18	//illegal value in MODE structure


typedef struct tagBITMAPFILEHEADER {
  WORD   bfType;
  DWORD  bfSize;
  WORD   bfReserved1;
  WORD   bfReserved2;
  DWORD  bfOffBits;
} BITMAPFILEHEADER, *PBITMAPFILEHEADER;

typedef struct tagBITMAPINFOHEADER
{
  DWORD                     biSize;
  LONG                      biWidth;
  LONG                      biHeight;
  WORD                      biPlanes;
  WORD                      biBitCount;
  DWORD                     biCompression;
  DWORD                     biSizeImage;
  LONG                      biXPelsPerMeter;
  LONG                      biYPelsPerMeter;
  DWORD                     biClrUsed;
  DWORD                     biClrImportant;
}
BITMAPINFOHEADER;

typedef struct tagRGBQUAD
{
  BYTE                      rgbBlue;
  BYTE                      rgbGreen;
  BYTE                      rgbRed;
  BYTE                      rgbReserved;
}
RGBQUAD;

typedef struct tagBITMAPINFO
{
  BITMAPINFOHEADER          bmiHeader;
  RGBQUAD                   bmiColors[1];

}
BITMAPINFO, *LPBITMAPINFO;



//STATUS  constants
#define	JPEG_ON						1	//JPEG capture on
#define	JPEG_OFF					0	//JPEG capture off
#define	CAP_ON						1	//caption on
#define	CAP_OFF						0	//caption off
//caption color constants
#define CAP_BLK						0x00	//black
#define CAP_WHT						0x10	//white
#define CAP_RED						0x20	//red
#define	CAP_BLU						0x30	//blue
#define CAP_GRN						0x40	//green
#define	CAP_YLW						0x50	//yellow
#define CAP_MGT						0x60	//magenta
#define	CAP_CYN						0x70	//cyan
//interlacing mode constants
#define	INT_INT						1	//interlaced
#define INT_DBL						0	//line doubling
#define INT_IRP						2	//line interpolation

//Bitmap size constants
#define	BMP_X_SML					128
#define	BMP_X_LRG					BMP_X_SML * 2
#define	BMP_Y_SML					96
#define	BMP_Y_LRG					BMP_Y_SML * 2

typedef struct
{
  void*  pjpg;//pointer to jpg image
  void*  pbmp;//pointer to bmp image
  int buffernumber;//id of the buffer when indicating data transfer complete back to the driver
  int jpegsize;//size of the compressed jpeg image
  
//  struct timval timestamp;//time that image was acquired

  //camera number taking the picture...relative to this board only
  //offsetting camera numbers for multiple boards is left to the user
  int camera;
  int videopresent; 

}imgstatus;


typedef struct
{
  unsigned char jpgBuffer[SYS_JPGSIZE];
  unsigned char bmpBuffer[SYS_BMPSIZE];
}BUFFER;

//      MODE structure
typedef struct
{
  DWORD                     format;	//NTSC, PAL
  DWORD                     bmpflip;	//bmp capture in Windows or natural lines order
  DWORD                     bmpcolor;	//bmp color or monochrome
  DWORD                     bmpsize;	//bmp large (256x192) or small (128x96)
  DWORD                     jpgsize;	//JPEG size: 704x480, 352x240, 640x480 (cropped), 320x240 (cropped)
  DWORD                     captionformat;	//format of the caption window
  DWORD                     captionpos;	//position of the caption window
  DWORD                     fontsize;	//caption font size
  DWORD                     compfactor;	//compression factor
  DWORD                     xpinit;	//crosspoint switch initial setting
}
MODE;

#define SEQ_MAX 128

typedef struct
{
  int                       jpegon;	//JPEG capture ON/OFF
  int                       captionmode; // caption mode for current capture: ON/OFF, caption color;
  int                       interlacemode;// interlaced, line doubling, line interpolation
  DWORD                     bqfull;	//  buffer queue full (cumulative); overrun
  DWORD                     incomplete;	//      compression incomplete (cumulative);
  DWORD                     zerror;	//      compression error (cumulative);
  unsigned char             SEQUENCE[SEQ_MAX][2];  // SEQUENCE[n][0] = channel(0-3)  
                                                  // SEQUENCE[n][1] = port(1-16)
  MODE mode;
}userstatus;


#endif
