//*********************** 615driver.h *****************************
//* This file contains special types, constants and
//* function prototypes for use with Sensoray 615 linux library.
//* Copyright (C) Sensoray Company 2002
//***********************************************************

#ifndef __615driver__h
#define __615driver__h

#define GOTINTERRUPT 0xDA
#define KILLINTERRUPT 0xAD

#define OURMAJOR 253

#define MAKEWORD(a, b) ((WORD) (((BYTE) (a)) | ((WORD) ((BYTE) (b))) << 8 ))
#define MAKELONG(a, b) ((LONG) (((WORD) (a)) | ((DWORD) ((WORD) (b))) << 16))
#define LOWORD(l) ((WORD) (l))
#define HIWORD(l) ((WORD) (((DWORD) (l) >> 16) & 0xFFFF))
#define LOBYTE(w) ((BYTE) (w))
#define HIBYTE(w) ((BYTE) (((WORD) (w) >> 8) & 0xFF))




///////////////////////////////////////////////////////////
// Registers' addresses
// Prefix:  C (codec)      ZR36060
//          P (PCI)        SAA7146
//          G (gate array) 
//                      D (decoder)        SAA7113
///////////////////////////////////////////////////////////
#define P_BASEODD1              0x000
#define P_BASEEVEN1             0x004
#define P_PROTADDR1             0x008
#define P_PITCH1                0x00c
#define P_PAGEMAP1              0x010
#define P_FORMAT1               0x014
#define P_BASEODD2              0x018
#define P_BASEEVEN2             0x01c
#define P_PROTADDR2             0x020
#define P_PITCH2                0x024
#define P_PAGEMAP2              0x028
#define P_FORMAT2               0x02c
#define P_BASEODD3              0x030
#define P_BASEEVEN3             0x034
#define P_PROTADDR3             0x038
#define P_PITCH3                0x03c
#define P_PAGEMAP3              0x040
#define P_FORMAT3               0x044
#define P_PCIBTV                0x048
#define P_D1SYNC                0x050
#define P_D1VIDEO               0x054
#define P_BRSCTL                0x058
#define P_HPSCTL                0x05c
#define P_HPSVS                 0x060
#define P_HPSVSG                0x064
#define P_HPSHPS                0x068
#define P_HPSHFS                0x06c
#define P_BCSCTL                0x070
#define P_CKEY                  0x074
#define P_HPSFORM               0x078
#define P_DEBICFG               0x07c
#define P_DEBICMD               0x080
#define P_DEBIPAGE              0x084
#define P_DEBIAD                0x088
#define P_I2CCTRL               0x08c
#define P_I2CSTAT               0x090
#define P_RPSPAGE0              0x0c4
#define P_RPSPAGE1              0x0c8
#define P_LCTS0                 0x0cc
#define P_LCTS1                 0x0d0
#define P_RPSTO0                0x0d4
#define P_RPSTO1                0x0d8
#define P_INTEN                 0x0dc
#define P_GPIO                  0x0e0
#define P_EC1SSR                0x0e4
#define P_ECT1R                 0x0ec
#define P_MC1                   0x0fc
#define P_MC2                   0x100
#define P_RPSADDR0              0x104
#define P_RPSADDR1              0x108
#define P_INTSTAT               0x10c
#define P_PSR                   0x110
#define P_SSR                   0x114
#define P_EC1R                  0x118
#define P_ECS2                  0x11c

#define C_LOAD                  0x000	//load parameters;
#define C_CFSTAT                0x001	//code FIFO status;
#define C_CINT                  0x002	//code interface;
#define C_CMODE                 0x003	//codec mode;
#define C_MAXBLK                0x005	//max block code;
#define C_MARKEN                0x006	//markers enable;
#define C_IRQMASK               0x007	//interrupt mask;
#define C_IRQSTAT               0x008	//interrupt status;
#define C_TNCV31                0x009	//target net code volume, 31:24;
#define C_TNCV23                0x00a	//target net code volume, 23:16;
#define C_TNCV15                0x00b	//target net code volume, 15:8;
#define C_TNCV7                 0x00c	//target net code volume, 7:0;
#define C_TDCV31                0x00d	//target data code volume, 31:24;
#define C_TDCV23                0x00e	//target data code volume, 23:16;
#define C_TDCV15                0x00f	//target data code volume, 15:8;
#define C_TDCV7                 0x010	//target data code volume, 7:0;
#define C_SCALEF15              0x011	//scale factor, 15:8;
#define C_SCALEF7               0x012	//scale factor, 7:0;
#define C_ALLF23                0x013	//allocation factor, 23:16;
#define C_ALLF15                0x014	//allocation factor, 15:8;
#define C_ALLF7                 0x015	//allocation factor, 7:0;
#define C_ACCV31                0x016	//accumulated code volume, 31:24;
#define C_ACCV23                0x017	//accumulated code volume, 23:16;
#define C_ACCV15                0x018	//accumulated code volume, 15:8;
#define C_ACCV7                 0x019	//accumulated code volume, 7:0;
#define C_ACTA31                0x01a	//accumulated total activity, 31:24;
#define C_ACTA23                0x01b	//accumulated total activity, 23:16;
#define C_ACTA15                0x01c	//accumulated total activity, 15:8;
#define C_ACTA7                 0x01d	//accumulated total activity, 7:0;
#define C_ACTB31                0x01e	//accumulated truncated bits, 31:24;
#define C_ACTB23                0x01f	//accumulated truncated bits, 23:16;
#define C_ACTB15                0x020	//accumulated truncated bits, 15:8;
#define C_ACTB7                 0x021	//accumulated truncated bits, 7:0;
#define C_DEVID                 0x022	//device ID;
#define C_REV                   0x023	//revision;
#define C_VIDEOCTL              0x030	//video control;
#define C_VIDEOPOL              0x031	//video polarity;
#define C_SCALE                 0x032	//scaling;
#define C_BACKY                 0x033	//background color, Y;
#define C_BACKU                 0x034	//background color, U;
#define C_BACKV                 0x035	//background color, V;
#define C_VTOT15                0x036	//vert total, 15:8;
#define C_VTOT7                 0x037	//vert total, 7:0;
#define C_HTOT9                 0x038	//hor total, 9:8;
#define C_HTOT7                 0x039	//hor total, 7:0;
#define C_VSYNC                 0x03a	//vert sync size;
#define C_HSYNC                 0x03b	//hor sync size;
#define C_BVSTART               0x03c	//blank vert start;
#define C_BHSTART               0x03d	//blank hor start;
#define C_BVEND15               0x03e	//blank vert end, 15:8;
#define C_BVEND7                0x03f	//blank vert end, 7:0;
#define C_BHEND9                0x040	//blank hor end, 9:8;
#define C_BHEND7                0x041	//blank hor end, 7:0;
#define C_AVSTART15             0x042	//active vert start, 15:8;
#define C_AVSTART7              0x043	//active vert start, 7:0;
#define C_AVEND15               0x044	//active vert end, 15:8;
#define C_AVEND7                0x045	//active vert end, 7:0;
#define C_AHSTART9              0x046	//active hor start, 9:8;
#define C_AHSTART7              0x047	//activehor start, 7:0;
#define C_AHEND9                0x048	//active hor end, 9:8;
#define C_AHEND7                0x049	//active hor end, 7:0;
#define C_SVSTART15             0x04a	//sub-image vert start, 15:8;
#define C_SVSTART7              0x04b	//sub-image vert start, 7:0;
#define C_SVEND15               0x04c	//sub-image vert end, 15:8;
#define C_SVEND7                0x04d	//sub-image vert end, 7:0;
#define C_SHSTART9              0x04e	//sub-image hor start, 9:8;
#define C_SHSTART7              0x04f	//sub-image hor start, 7:0;
#define C_SHEND9                0x050	//sub-image hor end, 9:8;
#define C_SHEND7                0x051	//sub-image hor end, 7:0;
#define C_JPEGMRK               0x060	//start of JPEG marker segment;

#define D_I2CADDR0				0x4a	//even 7113 I2C address
#define D_I2CADDR1				0x48	//odd 7113 I2C address
#define D_REGS					23	//# of 7113 regs to program

//Control constants
#define	SOFT_RESET				0x80000000	//7146 software reset

//Upload constants
#define UPLD_D1_B               0x04000400
#define UPLD_D1_A               0x02000200
#define UPLD_BRS                0x01000100
#define UPLD_HPS_H              0x00400040
#define UPLD_HPS_V              0x00200020
#define UPLD_DMA3               0x00100010
#define UPLD_DMA2               0x00080008
#define UPLD_DMA1               0x00040004
#define UPLD_ALLVIDEO			0x07640764
#define UPLD_DEBI               0x00020002
#define UPLD_IIC                0x00010001
#define UPLD_TR_E_1				0x00400040
#define UPLD_TR_D_1				0x00400000
#define UPLD_TR_E_D				0x00800080
#define UPLD_TR_D_D				0x00800000
#define UPLD_IIC_MASK           0x00000001

//DEBI address stubs
#define	A_SRAM					0x8000	//SRAM access, A[14:0] - SRAM addr
#define A_ZORAN					0x4000	//Zoran access, A[13:12]=ADDR[1:0], A[7:0]=internal addr
#define A_CAPBUF				0x2000	//caption buffer access, A[7:6]=channel#
#define A_CAPBUFARST			0x3000	//caption buffer address counter reset
#define A_GA					0x0000	//all other gate array register accesses

#define INTSTATUS_RPS1			0x10000000	//interrupt from RPS1
#define INTSTATUS_VSYNC			0x00000020	//interrupt from GPIO2
#define	INTSTATUS_ALL			INTSTATUS_VSYNC
#define INT_OFF					0x00000000	//mask all interrupts

#define STATUS_PSR_GPIO3		0x40	//GPIO3 status bit in PSR
#define STATUS_MC2_SIG0			0x800	//SIG0 status in MC2
#define STATUS_MC2_SIG1			0x1000	//SIG1 status in MC2

#define ISR_DEBI_S				0x00080000	//DEBI status int stat
#define ISR_PIN3				0x00000040	//GPIO3 int stat
#define PSR_PIN3				0x00000040	//GPIO3 PSR status
#define PSR_PIN2				0x00000020	//GPIO2 PSR status
#define PSR_PIN1				0x00000010	//GPIO1 PSR status

#define GPIO_RST                0x00200050	//all inputs, interrupt on GPIO2 (falling edge)
#define GPIO_QUIT               0x0	//all inputs

//I2C constants
#define I2C_ENABLE				0x01000100	//enable I2C pins in MC1;
#define I2C_STATSTUB            0x000	//I2C status reg stub (275 kHz)
#define I2C_ATTRSTART           0x3	//I2C attribute START
#define I2C_ATTRCONT            0x2	//I2C attribute CONT
#define I2C_ATTRSTOP            0x1	//I2C attribute STOP
#define I2C_ATTRNOP             0x0	//I2C attribute NOP
#define I2C_ERR                 0x2	//I2C error flag
#define I2C_BUSY                0x1	//I2C busy flag
#define I2C_ABORT               0x80	//I2C abort flag

//EEPROM constants
#define	EEPROM_ADDR				0xa0	//EEPROM I2C address
#define REVADDR					0x20	//revision data EEPROM address

//Crosspoint constants
#define XP_PREINIT				0xaaaa9999	//xp pre-initialization
#define XP_INIT					0xaaaa0123	//initial xp setting: inp's 1-4 connected
#define	CHAN_ON					0x9	//channel initialization
#define	CHAN_OFF				0xa	//channel off

//DEBI constants
#define DEBI_ENABLE             0x08000800	//enable DEBI pins in MC1;
#define DEBI_TO                 0x00800000	//DEBI t/o flag in SSR;
#define DEBI_E                  0x00040000	//DEBI event flag in PSR;
#define DEBI_S                  0x00080000	//DEBI status flag in PSR;
//#define DEBI_CFG_IMMEADACCESS   0x00010000      //DEBI CFG immeadiate access;
#define DEBI_CFG_IMMEADACCESS   0x03c00000	//DEBI CFG immeadiate access, timeout 15 PCI cycles;
#define DEBI_CFG_FAST           0x10000000	//DEBI fast mode enable;
#define DEBI_CFG_TO             22	//shifts for t/o value in DEBI_CFG;
#define DEBI_CFG_16             0x00080000	//DEBI 16-bit access enable; 0x00000000 for 8-bit
#define DEBI_CFG_INC            0x00040000	//enable DEBI address increment;
#define DEBI_CFG_BSWAP2         0x00100000	//2 byte swap
#define DEBI_CFG_BSWAP4         0x00200000	//4 byte swap
#define DEBI_CFG_TIMEROFF       0x00010000	//disable timer;
#define DEBI_CFG_XIRQ           0x80000000	//enable DEBI XIRQ;
#define DEBI_CMD_RD1            0x00030000	//read 1 byte;
#define DEBI_CMD_RD2            0x00050000	//read 2 bytes;
#define DEBI_CMD_WR1            0x00020000	//write 1 byte;
#define DEBI_CMD_WR2            0x00040000	//write 2 bytes;
#define DEBI_CMD_RD             0x00010000	//read 1 byte;
#define DEBI_CMD_WR             0x00000000	//write 1 byte;
#define DEBI_PAGE_IMMEADACCESS  0x00000000	//DEBI PAGE immeadiate access;
#define DEBI_PAGE_ENABLE        0x00000800	//DEBI paging enable;
#define DEBI_BLOCK              4096	//block size for JPEG code xfer; 256
//#define DEBI_BLOCK              128             //block size for JPEG code xfer; 256
#define	DEBI_DONE_WAIT			4	//number of times DEBI_S bit is read while polling

//7146 initialization constants
#define	D1_INIT					0x00000400	//D1 ports init value
#define BURST_INIT				0x1c00001f	//DEBI:128 dw burst; video ch1: 32 dw burst, 32 dw threshold
#define HPS_INIT				(0x50000000 | 4<<12)	//HPS:inp from portB,vert.offs.

#define HPSHPS_INIT_LRG			(1<<17 | 1<<18 | 1<<27)	//HPS,hor.prescaler
#define HPSHFS_INIT_LRG			(0x580<<12 | 0xe)	//HPS,hor.fine scaler
#define HPSVS_INIT_LRG_NTSC		(1<<31 | 0x266<<21 | 1<<15 | 0x26<<8 | 0x26<<1)	//HPS,vert.scale
#define HPSVS_INIT_LRG_PAL		(1<<31 | 0x296<<21 | 1<<15 | 0x26<<8 | 0x26<<1)	//HPS,vert.scale
#define HPSVSG_INIT_LRG			(1<<16 | 0x0102)	//HPS,vert.scale gain
#define HPSHPS_INIT_SML			(0<<17 | 4<<18 | 3<<27 | 0x0404)	//HPS,hor.prescaler
#define HPSHFS_INIT_SML			(0x466<<12 | 0xe)	//HPS,hor.fine scaler

#define HPSVS_INIT_SML_NTSC		(1<<31 | 0x333<<21 | 4<<15 | 0x33<<8 | 0x33<<1)	//HPS,vert.scale
#define HPSVS_INIT_SML_PAL		(1<<31 | 0x34b<<21 | 4<<15 | 0x33<<8 | 0x33<<1)	//HPS,vert.scale
#define HPSVSG_INIT_SML			(2<<16 | 0x0304)	//HPS,vert.scale gain

#define	SCALER_INP_LINES_PIX_N	(504 << 16 | 704)	//active lines/pixels @ 7146 scaler input, NTSC
#define	SCALER_INP_LINES_PIX_P	(544 << 16 | 704)	//active lines/pixels @ 7146 scaler input, PAL

#define BCS_INIT				0x80400040	//Bright.,Contrast,Saturation
#define HPSFORM_INIT_MONO		0x06000000	//monochrome
#define HPSFORM_INIT_YCRCB		0x00000000	//YCrCb
#define HPSFORM_INIT_RGB		(2<<30 | 1<<24)	//RGB
#define VDP_DEBI_ENABLE			0x0c000c00	//enable video port and DEBI pins in MC1;
#define EN_DMA1_RPS0			0x10401040	//enable RPS0 and video1
#define EN_RPS1					0x20002000	//enable RPS1
#define	DSBL_RPS				0x30400000	//disable RPS1,2, video1
#define DSBL_RPS1				0x20000000	//disable RPS1
#define DSBL_DEBI				0x00800000	//disable DEBI xfer

//Gate array constants
#define	R0						0x0<<1	//internal registers' addresses
#define	R1						0x1<<1
#define	R2						0x2<<1
#define	R3						0x3<<1
#define	R4						0x4<<1
#define	R5						0x5<<1
#define	R6						0x6<<1
#define	R7						0x7<<1
#define	R8						0x8<<1
#define	R9						0x9<<1
#define	R10						0xa<<1
#define	R11						0xb<<1
#define	R12						0xc<<1
#define	R13						0xd<<1
#define	R14						0xe<<1
#define	R15						0xf<<1

#define	CLR_WHT					0xd2
#define	CLR_BLK					0x12
#define	CLR_RED					0x84
#define	CLR_BLU					0x62
#define	CLR_GRN					0x80
#define	CLR_YLW					0xc2
#define	CLR_MGT					0x9c
#define	CLR_CYN					0xd8

BYTE                      CLR[8] =
  { CLR_BLK, CLR_WHT, CLR_RED, CLR_BLU, CLR_GRN, CLR_YLW, CLR_MGT, CLR_CYN };

int                       CHAN[4] = { 0, 1, 3, 2 };	//channel translation (fix for channels 2 and 3 crossed)

#define R4_ZRESET				0x1	//Zoran RESET
#define	R4_ZSLEEP				0x2	//Zoran SLEEP
#define	R5_START_XPSM			0x1	//START (BUSY) bit of crosspoint switch control state machine
#define	R6_OUTPINEN				0x2	//enable GA output pins

#define	CAPTION_LENGTH			64	//caption length (char's)
#define	TIMESTAMPLENGTH			8	//00:00:00
#define	DATESTAMPLENGTH			11	//Wed Jan 02 + 1 space
#define	YEARSTAMPLENGTH			4	//2002

//ZR36060 constants
#define Z_ADDR_MSB				1 << 12	//Zoran internal address MSB register
#define Z_ADDR_LSB				2 << 12	//Zoran internal address LSB register
#define Z_DATA					3 << 12	//Zoran data register
#define CC_LOADBUSY             0x80	//load busy flag
#define CC_TIMEOUT              20	//load timeout
#define	CC_RESETSYNC			0x01	//reset sync gen
#define CC_STARTSYNC			0x00	//start sync gen

#define	Z_SYNC_BYTES			20	//bytes to write from SYNC_XXX[]
#define	Z_SYNC_START			0x36	//start Z address for sync data
#define	Z_SUBIMG_BYTES			8	//bytes to write from SUBIMG_XXX[]
#define	Z_SUBIMG_START			0x4a	//start Z address for subimg data
#define	Z_VSIZE_BYTES			2	//bytes to write from VSTART_XXX[]
#define	Z_VSIZE_START			0x65	//start Z address for vsize data
#define	Z_SCALE_BYTES			1	//bytes to write
#define	Z_SCALE_START			0x32	//start Z address to write internal Zoran scaling mode
#define	Z_SCALE1				0	//no 1:2 scaling
#define	Z_SCALE2				5	//1:2 scaling in both directions
#define	Z_MRK_X					0x65	//start Z address for JPEG marker section image Y,X sizes
#define	Z_MRK_BYTES				4	//bytes to write from JPEG_MRK_XXX[][]

//RPS command codes
#define RPS_CLRSIGNAL           0x00000000	//CLEAR SIGNAL
#define RPS_NOP                 0x00000000	//NOP
#define RPS_SETSIGNAL           0x10000000	//SET SIGNAL
#define RPS_PAUSE               0x20000000	//PAUSE
#define RPS_CHKLATE             0x30000000	//CHECK-LATE
#define RPS_UPLOAD              0x40000000	//UPLOAD
#define RPS_STOP                0x50000000	//STOP
#define RPS_IRQ                 0x60000000	//INTERRUPT
#define RPS_JUMP                0x80000000	//JUMP
#define RPS_LDREG               0x90000000	//LDREG
#define RPS_STREG               0xa0000000	//STREG
#define RPS_MSKLOAD             0xc0000000	//MASKLOAD

#define RPS_OR                  0x08000000	//OR conditions
#define RPS_INV                 0x04000000	//invert conditions
#define RPS_GPIO3               0x00100000	//GPIO3
#define RPS_HS                  0x00008000	//HS done
#define RPS_HT					0x00010000	//HT done
#define RPS_VBIA                0x00000400	//VBI_A
#define RPS_VBIB                0x00000200	//VBI_B
#define RPS_HPS                 0x00000020	//HPS done
#define RPS_VTD1                0x00000004	//VTD1
#define RPS_DEBI                0x00000002	//DEBI done
#define RPS_SIG0                0x00200000	//RPS signal 0 (in RPS command)
#define RPS_STAT_SIG0           0x00000800	//RPS signal 0 (in MC2)
#define RPS_SIG1                0x00400000	//RPS signal 1 (in RPS command)
#define RPS_STAT_SIG1           0x00001000	//RPS signal 1 (in MC2)
#define RPS_SIG2                0x00800000	//RPS signal 2 (in RPS command)
#define RPS_STAT_SIG2           0x00002000	//RPS signal 2 (in MC2)
#define RPS_SIG3                0x01000000	//RPS signal 3 (in RPS command)
#define RPS_SIG4                0x02000000	//RPS signal 4 (in RPS command)
#define RPS_IRQI0               0x08000000	//RPS interrupt I0;
#define RPS_E_FIDA              0x00000800	//RPS even field 2 portA;
#define RPS_E_FIDB              0x00002000	//RPS even field 2 portB;
#define RPS_O_FIDA              0x00001000	//RPS odd field 2 portA;
#define RPS_O_FIDB              0x00004000	//RPS odd field 2 portB;
#define RPS_DEBI_UPLD           0x6	//DEBI upload const

//Video DMA control constants
#define DMA_MAP                 0x800	//DMA mapping enable
#define DMA_PROTVIOL            0x8	//DMA protection violation handling
#define	DMA_SWAP2				1	//2 byte swap
#define	DMA_NOSWAP				0	//no swap


BYTE                      REG_C_NTSC[1024] = {
  // General Control Registers
  0x00,				// load Parameter
  0x00,				// code FIFO Status
  0x80,				// code Interface   -- slave, 16 bit
  0xa6,				// codec Mode
  0x00,				// reserved
  0xf0,				// maximum Block Code Volume
  0x98,				// markers Enable
  0x00,				// interrupt Mask
  0x00,				// interrupt Status

  0x00, 0x0c, 0x35, 0x00,	// target Net Code Volume
  0x00, 0x0c, 0x35, 0x00,	// target Data Code Volume
  0x00, 0x90,			// scale Factor
  0xff, 0xff, 0xff,		// allocation Factor
  0x00, 0x00, 0x00, 0x00,	// accumulated Code Volume
  0x00, 0x00, 0x00, 0x00,	// accumulated Total Activity
  0x00, 0x00, 0x00, 0x00,	// accumulated Truncated Bits

  //ID and Testing Registers
  0x00, 0x00,			// identification
  0x00, 0x00,			// testControl

  // Reserved
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00,

  //Video Registers
  0xc5,				// video Control  0xc5 - sync master
  0x40,				// video Polarity   -- vsync low, hsync(psync) low?
  0x00,				// scaling  -- 1:1
  // background Color
  0x00, 0x00, 0x00,		//      Y, U, V     *** decompression only ***
  // sync Generator
  0x04, 0x89,			//      Vtotal             (480+24+8)*2
  0x02, 0xff,			//      Htotal                          (720+40+16)
  0x02,				//      VsyncSize                       0x17
  0x27,				//      HsyncSize                       
  0x1b,				//      BVstart                         
  0x2b,				//      BHstart                         
  0x01, 0xfc,			//      BVend                                                   
  0x02, 0xfb,			//      BHend
  // active Area     
  0x00, 0x05,			//      Vstart                          24 0x1b
  0x01, 0xe5,			//      Vend                            504 0x1fc
  0x00, 0x37,			//      Hstart          0x2d    
  0x02, 0xf7,			//      Hend            0x2fd

  // sub-Image Window active Area
  0x00, 0x50,			//      SVstart large 32x2
  0x00, 0x90,			//      SVend
  0x00, 0x3f,			//      SHstart
  0x02, 0x3f,			//      SHend

  // Reserved
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00,

  //JPEG Marker Segments
  0xff,				// SOF0_H
  0xc0,				// SOF0_L
  0x00,				// LEN_H
  0x11,				// LEN_L
  0x08,				// P
  0x01,				// Y_H 00       01      *
  0xe0,				// Y_L f0       e0      *
  0x02,				// X_H 01       02      *
  0xc0,				// X_L 40       e0      *
  0x03,				// Nf
  0x00,				// CY
  0x21,				// HY VY
  0x00,				// TqY
  0x01,				// CU
  0x11,				// HU VU
  0x01,				// TqU
  0x02,				// CV
  0x11,				// HV VV
  0x01,				// TqV
  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00, 0x00,
  0xff,				// SOS_H
  0xda,				// SOS_L
  0x00,				// LEN_H
  0x0c,				// LEN_L
  0x03,				// Ns
  0x00,				// CY
  0x00,				// TYd TYa
  0x01,				// CU
  0x11,				// TUd TUa
  0x02,				// CV
  0x11,				// TVd TVa
  0x00,				// const
  0x3f,				// const
  0x00,				// const
  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0xff,				// DRI_H
  0xdd,				// DRI_L
  0x00,				// LEN_H
  0x04,				// LEN_L
  0x00,				// RI_H
  0x08,				// RI_L
  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00,

  0xff,				// DQT_H
  0xdb,				// DQT_L
  0x00,				// LEN_H
  0x84,				// LEN_L

  // DTQ
  0x00,				// Pq,Tq of first table
  0x10, 0x0b, 0x0c, 0x0e, 0x0c, 0x0a, 0x10, 0x0e,
  0x0d, 0x0e, 0x12, 0x11, 0x10, 0x13, 0x18, 0x28,
  0x1a, 0x18, 0x16, 0x16, 0x18, 0x31, 0x23, 0x25,
  0x1d, 0x28, 0x3a, 0x33, 0x3d, 0x3c, 0x39, 0x33,
  0x38, 0x37, 0x40, 0x48, 0x5c, 0x4e, 0x40, 0x44,
  0x57, 0x45, 0x37, 0x38, 0x50, 0x6d, 0x51, 0x57,
  0x5f, 0x62, 0x67, 0x68, 0x67, 0x3e, 0x4d, 0x71,
  0x79, 0x70, 0x64, 0x78, 0x5c, 0x65, 0x67, 0x63,

  0x01,				// Pq,Tq of second table
  0x11, 0x12, 0x12, 0x18, 0x15, 0x18, 0x2f, 0x1a,
  0x1a, 0x2f, 0x63, 0x42, 0x38, 0x42, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,

  0x00,				// unused
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,

  0x00,				// unused
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,


  0xff,				//DHT_H
  0xc4,				//DHT_L
  0x01,				//LEN_H
  0xa2,				//LEN_L

  // DHT
  // JPEG DHT Segment for YCrCb omitted from MJPG data.
  0x00,
  // DC0 length specifications
  0x00, 0x01, 0x05, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  // DC0 symbol definitions
  0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B,

  0x01,
  // DC1 length specifications
  0x00, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00,
  0x00, 0x00, 0x00, 0x00,
  // DC1 symbol definitions
  0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B,

  0x10,
  // AC0 length specifications
  0x00, 0x02, 0x01, 0x03, 0x03, 0x02, 0x04, 0x03, 0x05, 0x05, 0x04, 0x04,
  0x00, 0x00, 0x01, 0x7D,
  // AC0 symbol definitions
  0x01, 0x02, 0x03, 0x00, 0x04, 0x11, 0x05, 0x12, 0x21, 0x31, 0x41, 0x06,
  0x13, 0x51, 0x61, 0x07,
  0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xA1, 0x08, 0x23, 0x42, 0xB1, 0xC1,
  0x15, 0x52, 0xD1, 0xF0,
  0x24, 0x33, 0x62, 0x72, 0x82, 0x09, 0x0A, 0x16, 0x17, 0x18, 0x19, 0x1A,
  0x25, 0x26, 0x27, 0x28,
  0x29, 0x2A, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x43, 0x44, 0x45,
  0x46, 0x47, 0x48, 0x49,
  0x4A, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x63, 0x64, 0x65,
  0x66, 0x67, 0x68, 0x69,
  0x6A, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x83, 0x84, 0x85,
  0x86, 0x87, 0x88, 0x89,
  0x8A, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9A, 0xA2, 0xA3,
  0xA4, 0xA5, 0xA6, 0xA7,
  0xA8, 0xA9, 0xAA, 0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0xB7, 0xB8, 0xB9, 0xBA,
  0xC2, 0xC3, 0xC4, 0xC5,
  0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6, 0xD7, 0xD8,
  0xD9, 0xDA, 0xE1, 0xE2,
  0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xF1, 0xF2, 0xF3, 0xF4,
  0xF5, 0xF6, 0xF7, 0xF8,
  0xF9, 0xFA,

  0x11,
  // AC1 length specifications
  0x00, 0x02, 0x01, 0x02, 0x04, 0x04, 0x03, 0x04, 0x07, 0x05, 0x04, 0x04,
  0x00, 0x01, 0x02, 0x77,
  // AC1 symbol definitions
  0x00, 0x01, 0x02, 0x03, 0x11, 0x04, 0x05, 0x21, 0x31, 0x06, 0x12, 0x41,
  0x51, 0x07, 0x61, 0x71,
  0x13, 0x22, 0x32, 0x81, 0x08, 0x14, 0x42, 0x91, 0xA1, 0xB1, 0xC1, 0x09,
  0x23, 0x33, 0x52, 0xF0,
  0x15, 0x62, 0x72, 0xD1, 0x0A, 0x16, 0x24, 0x34, 0xE1, 0x25, 0xF1, 0x17,
  0x18, 0x19, 0x1A, 0x26,
  0x27, 0x28, 0x29, 0x2A, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x43, 0x44,
  0x45, 0x46, 0x47, 0x48,
  0x49, 0x4A, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x63, 0x64,
  0x65, 0x66, 0x67, 0x68,
  0x69, 0x6A, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x82, 0x83,
  0x84, 0x85, 0x86, 0x87,
  0x88, 0x89, 0x8A, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9A,
  0xA2, 0xA3, 0xA4, 0xA5,
  0xA6, 0xA7, 0xA8, 0xA9, 0xAA, 0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0xB7, 0xB8,
  0xB9, 0xBA, 0xC2, 0xC3,
  0xC4, 0xC5, 0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6,
  0xD7, 0xD8, 0xD9, 0xDA,
  0xE2, 0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xF2, 0xF3, 0xF4,
  0xF5, 0xF6, 0xF7, 0xF8,
  0xF9, 0xFA,

  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00, 0x00, 0x00,

  0xff,				// APP_H
  0xe0,				// APP_L
  0x00,				// LEN_H
  0x10,				// LEN_L
  0x4a, 0x46, 0x49, 0x46,	// APP segment
  0x00, 0x01, 0x01, 0x01,
  0x01, 0x2c, 0x01, 0x2c,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0xff,				// COM_H
  0xfe,				// COM_L
  0x00,				// LEN_H
  0x3e,				// LEN_L
  0x00, 0x00, 0x00, 0x00,	// COM segment
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00
};

BYTE                      JPEG_MRK_NTSC[4][4] = { {0x01, 0xe0, 0x02, 0xc0},	//480V x 704H           full
{0x00, 0xf0, 0x01, 0x60},	//240V x 352H           half
{0x01, 0xe0, 0x02, 0x80},	//480V x 640H           full clipped
{0x00, 0xf0, 0x01, 0x40}
};				//240V x 320H           half clipped

BYTE                      JPEG_MRK_PAL[4][4] = {
  {
   0x02, 0x20, 0x02, 0xc0}
  ,				//544V x 704H           full
  {
   0x01, 0x10, 0x01, 0x60}
  ,				//272V x 352H           half
  {
   0x01, 0xe0, 0x02, 0x80}
  ,				//480V x 640H           full clipped ?? not supported
  {
   0x00, 0xf0, 0x01, 0x40}
};				//240V x 320H           half clipped ??         -"-

#define		HSTART_LO_FUL_NTSC			0x37
#define		HEND_LO_FUL_NTSC			0xf7
#define		HSTART_LO_CLP_NTSC			0x57
#define		HEND_LO_CLP_NTSC			0xd7

#define		HSTART_LO_FUL_PAL			0x33
#define		HEND_LO_FUL_PAL				0xf3
#define		HSTART_LO_CLP_PAL			0x57
#define		HEND_LO_CLP_PAL				0xd7


BYTE                      SYNC_NTSC[2][Z_SYNC_BYTES] = {
  //Full unclipped
  // sync Generator
  {0x04, 0x91,			//      Vtotal             0x481 0x491
   0x02, 0xff,			//      Htotal                          (720+40+16)
   0x3a,			//      VsyncSize                       0x17
   0x27,			//      HsyncSize                       
   0x3d,			//      BVstart                         
   0x2b,			//      BHstart                         
   0x02, 0x1f,			//      BVend                                           
   0x02, 0xfb,			//      BHend
   // active Area     
   0x00, 0x05,			//      Vstart                          24 0x1b
   0x01, 0xe5,			//      Vend                            504 0x1fc
   0x00, HSTART_LO_FUL_NTSC,	//      Hstart          0x2d    
   0x02, HEND_LO_FUL_NTSC},	//      Hend            0x2fd
  //Full clipped
  // sync Generator
  {0x04, 0x81,			//      Vtotal             (480+24+8)*2
   0x02, 0xff,			//      Htotal                          (720+40+16)
   0x3a,			//      VsyncSize                       0x17
   0x27,			//      HsyncSize                       
   0x3d,			//      BVstart                         
   0x2b,			//      BHstart                         
   0x02, 0x1f,			//      BVend                                           
   0x02, 0xfb,			//      BHend
   // active Area     
   0x00, 0x05,			//      Vstart                          24 0x1b
   0x01, 0xe5,			//      Vend                            504 0x1fc
   0x00, HSTART_LO_CLP_NTSC,	//      Hstart          0x2d    
   0x02, HEND_LO_CLP_NTSC}	//      Hend            0x2fd
};

BYTE                      SYNC_PAL[2][Z_SYNC_BYTES] = {
  //Full unclipped
  // sync Generator
  {0x05, 0x81,			//      Vtotal
   0x02, 0xff,			//      Htotal                          (720+40+16)
   0x3a,			//      VsyncSize                       0x17
   0x27,			//      HsyncSize                       
   0x3d,			//      BVstart                         
   0x2b,			//      BHstart                         
   0x02, 0x5f,			//      BVend                                           
   0x02, 0xfb,			//      BHend
   // active Area     
   0x00, 0x05,			//      Vstart                          24 0x1b
   0x02, 0x25,			//      Vend                            504 0x1fc
   0x00, HSTART_LO_FUL_PAL,	//      Hstart          0x2d    
   0x02, HEND_LO_FUL_PAL},	//      Hend            0x2fd
  //Full clipped (not supported for PAL)
  // sync Generator
  {0x04, 0x81,			//      Vtotal             (480+24+8)*2
   0x02, 0xff,			//      Htotal                          (720+40+16)
   0x3a,			//      VsyncSize                       0x17
   0x27,			//      HsyncSize                       
   0x3d,			//      BVstart                         
   0x2b,			//      BHstart                         
   0x02, 0x1f,			//      BVend                                           
   0x02, 0xfb,			//      BHend
   // active Area     
   0x00, 0x05,			//      Vstart                          24 0x1b
   0x01, 0xe5,			//      Vend                            504 0x1fc
   0x00, HSTART_LO_CLP_NTSC,	//      Hstart          0x2d    
   0x02, HEND_LO_CLP_NTSC}	//      Hend            0x2fd
};
BYTE                      SUBIMG_NTSC[2][2][4][3][8] = {
  //[2]... - clipped/unclipped
  //[][2]... - font size
  //[][][4]... - window position
  //[][][][3]... - window format

  //unclipped
  0x00, 0x10,			//      SVstart small UL 8x8
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_FUL_NTSC + 8 + 0x40,	//      SHend

  0x00, 0x10,			//      SVstart small UL 16x4
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_FUL_NTSC + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart small UL 32x2
  0x00, 0x30,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_FUL_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 8x8
  0x00, 0x90,			//      SVend
  0x02, HEND_LO_FUL_NTSC - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 16x4
  0x00, 0x50,			//      SVend
  0x02, HEND_LO_FUL_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 32x2
  0x00, 0x30,			//      SVend
  0x01, HEND_LO_FUL_NTSC - 8,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x01, 0x60,			//      SVstart small LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_FUL_NTSC + 8 + 0x40,	//      SHend

  0x01, 0xa0,			//      SVstart small LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_FUL_NTSC + 8 + 0x80,	//      SHend

  0x01, 0xc0,			//      SVstart small LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_FUL_NTSC + 8,	//      SHend

  0x01, 0x60,			//      SVstart small LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_FUL_NTSC - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x01, 0xa0,			//      SVstart small LR 16x4
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_FUL_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x01, 0xc0,			//      SVstart small LR 32x2
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_FUL_NTSC - 8,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 8x8
  0x01, 0x10,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_FUL_NTSC + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart large UL 16x4
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_FUL_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 32x2
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x02, HSTART_LO_FUL_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 8x8
  0x01, 0x10,			//      SVend
  0x02, HEND_LO_FUL_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 16x4
  0x00, 0x90,			//      SVend
  0x01, HEND_LO_FUL_NTSC - 8,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 32x2
  0x00, 0x50,			//      SVend
  0x00, HEND_LO_FUL_NTSC - 8,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_FUL_NTSC + 8 + 0x80,	//      SHend

  0x01, 0x60,			//      SVstart large LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_FUL_NTSC + 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_NTSC + 8,	//      SHstart
  0x02, HSTART_LO_FUL_NTSC + 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_FUL_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend

  0x01, 0x60,			//      SVstart large LR 16x4
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_FUL_NTSC - 8,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend 

  0x01, 0xa0,			//      SVstart large LR 32x2
  0x01, 0xe0,			//      SVend
  0x00, HEND_LO_FUL_NTSC - 8,	//      SHstart
  0x02, HEND_LO_FUL_NTSC - 8,	//      SHend


  //clipped
  0x00, 0x10,			//      SVstart small UL 8x8
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x40,	//      SHend

  0x00, 0x10,			//      SVstart small UL 16x4
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart small UL 32x2
  0x00, 0x30,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 8x8
  0x00, 0x90,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 16x4
  0x00, 0x50,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 32x2
  0x00, 0x30,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0x60,			//      SVstart small LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x40,	//      SHend

  0x01, 0xa0,			//      SVstart small LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x01, 0xc0,			//      SVstart small LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x01, 0x60,			//      SVstart small LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0xa0,			//      SVstart small LR 16x4
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0xc0,			//      SVstart small LR 32x2
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 8x8
  0x01, 0x10,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart large UL 16x4
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 32x2
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x02, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 8x8
  0x01, 0x10,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 16x4
  0x00, 0x90,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 32x2
  0x00, 0x50,			//      SVend
  0x00, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x01, 0x60,			//      SVstart large LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x02, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0x60,			//      SVstart large LR 16x4
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LR 32x2
  0x01, 0xe0,			//      SVend
  0x00, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend
};


BYTE                      SUBIMG_PAL[2][2][4][3][8] = {
  //[2]... - clipped/unclipped
  //[][2]... - font size
  //[][][4]... - window position
  //[][][][3]... - window format

  //unclipped
  0x00, 0x10,			//      SVstart small UL 8x8
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x00, HSTART_LO_FUL_PAL + 8 + 0x40,	//      SHend

  0x00, 0x10,			//      SVstart small UL 16x4
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x00, HSTART_LO_FUL_PAL + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart small UL 32x2
  0x00, 0x30,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x01, HSTART_LO_FUL_PAL + 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 8x8
  0x00, 0x90,			//      SVend
  0x02, HEND_LO_FUL_PAL - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 16x4
  0x00, 0x50,			//      SVend
  0x02, HEND_LO_FUL_PAL - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 32x2
  0x00, 0x30,			//      SVend
  0x01, HEND_LO_FUL_PAL - 8,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x01, 0x60,			//      SVstart small LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x00, HSTART_LO_FUL_PAL + 8 + 0x40,	//      SHend

  0x01, 0xa0,			//      SVstart small LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x00, HSTART_LO_FUL_PAL + 8 + 0x80,	//      SHend

  0x01, 0xc0,			//      SVstart small LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x01, HSTART_LO_FUL_PAL + 8,	//      SHend

  0x01, 0x60,			//      SVstart small LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_FUL_PAL - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x01, 0xa0,			//      SVstart small LR 16x4
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_FUL_PAL - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x01, 0xc0,			//      SVstart small LR 32x2
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_FUL_PAL - 8,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 8x8
  0x01, 0x10,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x00, HSTART_LO_FUL_PAL + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart large UL 16x4
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x01, HSTART_LO_FUL_PAL + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 32x2
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x02, HSTART_LO_FUL_PAL + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 8x8
  0x01, 0x10,			//      SVend
  0x02, HEND_LO_FUL_PAL - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 16x4
  0x00, 0x90,			//      SVend
  0x01, HEND_LO_FUL_PAL - 8,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 32x2
  0x00, 0x50,			//      SVend
  0x00, HEND_LO_FUL_PAL - 8,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x00, HSTART_LO_FUL_PAL + 8 + 0x80,	//      SHend

  0x01, 0x60,			//      SVstart large LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x01, HSTART_LO_FUL_PAL + 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_FUL_PAL + 8,	//      SHstart
  0x02, HSTART_LO_FUL_PAL + 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_FUL_PAL - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x01, 0x60,			//      SVstart large LR 16x4
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_FUL_PAL - 8,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LR 32x2
  0x01, 0xe0,			//      SVend
  0x00, HEND_LO_FUL_PAL - 8,	//      SHstart
  0x02, HEND_LO_FUL_PAL - 8,	//      SHend


  //clipped (not supported for PAL)
  0x00, 0x10,			//      SVstart small UL 8x8
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x40,	//      SHend

  0x00, 0x10,			//      SVstart small UL 16x4
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart small UL 32x2
  0x00, 0x30,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 8x8
  0x00, 0x90,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 16x4
  0x00, 0x50,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart small UR 32x2
  0x00, 0x30,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0x60,			//      SVstart small LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x40,	//      SHend

  0x01, 0xa0,			//      SVstart small LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x01, 0xc0,			//      SVstart small LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x01, 0x60,			//      SVstart small LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x40,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0xa0,			//      SVstart small LR 16x4
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0xc0,			//      SVstart small LR 32x2
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 8x8
  0x01, 0x10,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x00, 0x10,			//      SVstart large UL 16x4
  0x00, 0x90,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UL 32x2
  0x00, 0x50,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x02, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 8x8
  0x01, 0x10,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 16x4
  0x00, 0x90,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0x10,			//      SVstart large UR 32x2
  0x00, 0x50,			//      SVend
  0x00, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LL 8x8
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x00, HSTART_LO_CLP_NTSC + 8 + 0x80,	//      SHend

  0x01, 0x60,			//      SVstart large LL 16x4
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x01, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LL 32x2
  0x01, 0xe0,			//      SVend
  0x00, HSTART_LO_CLP_NTSC + 8,	//      SHstart
  0x02, HSTART_LO_CLP_NTSC + 8,	//      SHend

  0x00, 0xe0,			//      SVstart large LR 8x8
  0x01, 0xe0,			//      SVend
  0x02, HEND_LO_CLP_NTSC - 8 - 0x80,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0x60,			//      SVstart large LR 16x4
  0x01, 0xe0,			//      SVend
  0x01, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend

  0x01, 0xa0,			//      SVstart large LR 32x2
  0x01, 0xe0,			//      SVend
  0x00, HEND_LO_CLP_NTSC - 8,	//      SHstart
  0x02, HEND_LO_CLP_NTSC - 8,	//      SHend
};

BYTE                      VSIZE_NTSC[2] = {
  0x01, 0xe0			//480
};

BYTE                      VSIZE_PAL[2] = {
  0x02, 0x20			//544
};

BYTE                      REG_C_PAL[1024] = {
  // General Control Registers
  0x00,				// load Parameter
  0x00,				// code FIFO Status
  0x80,				// code Interface   -- slave, 16 bit
  0xa6,				// codec Mode
  0x00,				// reserved
  0xf0,				// maximum Block Code Volume
  0x98,				// markers Enable
  0x00,				// interrupt Mask
  0x00,				// interrupt Status
  0x00, 0x0c, 0x35, 0x00,	// target Net Code Volume
  0x00, 0x0c, 0x35, 0x00,	// target Data Code Volume
  0x00, 0x90,			// scale Factor
  0xff, 0xff, 0xff,		// allocation Factor
  0x00, 0x00, 0x00, 0x00,	// accumulated Code Volume
  0x00, 0x00, 0x00, 0x00,	// accumulated Total Activity
  0x00, 0x00, 0x00, 0x00,	// accumulated Truncated Bits

  //ID and Testing Registers
  0x00, 0x00,			// identification
  0x00, 0x00,			// testControl

  // Reserved
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00,

  //Video Registers
  0xc5,				// video Control  0xc5 - sync master
  0x40,				// video Polarity   -- vsync low, hsync(psync) low?
  0x00,				// scaling  -- 1:1
  // background Color
  0x00, 0x00, 0x00,		//      Y, U, V     *** decompression only ***
  // sync Generator
  0x04, 0x89,			//      Vtotal             (480+24+8)*2
  0x02, 0xff,			//      Htotal                          (720+40+16)
  0x02,				//      VsyncSize                       0x17
  0x27,				//      HsyncSize                       
  0x1b,				//      BVstart                         
  0x2b,				//      BHstart                         
  0x01, 0xfc,			//      BVend                                                   
  0x02, 0xfb,			//      BHend
  // active Area     
  0x00, 0x05,			//      Vstart                          24 0x1b
  0x01, 0xe5,			//      Vend                            504 0x1fc
  0x00, 0x37,			//      Hstart          0x2d    
  0x02, 0xf7,			//      Hend            0x2fd

  // sub-Image Window active Area
  0x00, 0x50,			//      SVstart large 32x2
  0x00, 0x90,			//      SVend
  0x00, 0x3f,			//      SHstart
  0x02, 0x3f,			//      SHend

  // Reserved
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00,

  //JPEG Marker Segments
  0xff,				// SOF0_H
  0xc0,				// SOF0_L
  0x00,				// LEN_H
  0x11,				// LEN_L
  0x08,				// P
  0x01,				// Y_H 00       01      *
  0xe0,				// Y_L f0       e0      *
  0x02,				// X_H 01       02      *
  0xc0,				// X_L 40       e0      *
  0x03,				// Nf
  0x00,				// CY
  0x21,				// HY VY
  0x00,				// TqY
  0x01,				// CU
  0x11,				// HU VU
  0x01,				// TqU
  0x02,				// CV
  0x11,				// HV VV
  0x01,				// TqV
  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00, 0x00,
  0xff,				// SOS_H
  0xda,				// SOS_L
  0x00,				// LEN_H
  0x0c,				// LEN_L
  0x03,				// Ns
  0x00,				// CY
  0x00,				// TYd TYa
  0x01,				// CU
  0x11,				// TUd TUa
  0x02,				// CV
  0x11,				// TVd TVa
  0x00,				// const
  0x3f,				// const
  0x00,				// const
  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0xff,				// DRI_H
  0xdd,				// DRI_L
  0x00,				// LEN_H
  0x04,				// LEN_L
  0x00,				// RI_H
  0x08,				// RI_L
  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00,

  0xff,				// DQT_H
  0xdb,				// DQT_L
  0x00,				// LEN_H
  0x84,				// LEN_L

  // DTQ
  0x00,				// Pq,Tq of first table
  0x10, 0x0b, 0x0c, 0x0e, 0x0c, 0x0a, 0x10, 0x0e,
  0x0d, 0x0e, 0x12, 0x11, 0x10, 0x13, 0x18, 0x28,
  0x1a, 0x18, 0x16, 0x16, 0x18, 0x31, 0x23, 0x25,
  0x1d, 0x28, 0x3a, 0x33, 0x3d, 0x3c, 0x39, 0x33,
  0x38, 0x37, 0x40, 0x48, 0x5c, 0x4e, 0x40, 0x44,
  0x57, 0x45, 0x37, 0x38, 0x50, 0x6d, 0x51, 0x57,
  0x5f, 0x62, 0x67, 0x68, 0x67, 0x3e, 0x4d, 0x71,
  0x79, 0x70, 0x64, 0x78, 0x5c, 0x65, 0x67, 0x63,

  0x01,				// Pq,Tq of second table
  0x11, 0x12, 0x12, 0x18, 0x15, 0x18, 0x2f, 0x1a,
  0x1a, 0x2f, 0x63, 0x42, 0x38, 0x42, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63,

  0x00,				// unused
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,

  0x00,				// unused
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,


  0xff,				//DHT_H
  0xc4,				//DHT_L
  0x01,				//LEN_H
  0xa2,				//LEN_L

  // DHT
  // JPEG DHT Segment for YCrCb omitted from MJPG data.
  0x00,
  // DC0 length specifications
  0x00, 0x01, 0x05, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  // DC0 symbol definitions
  0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B,

  0x01,
  // DC1 length specifications
  0x00, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00,
  0x00, 0x00, 0x00, 0x00,
  // DC1 symbol definitions
  0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B,

  0x10,
  // AC0 length specifications
  0x00, 0x02, 0x01, 0x03, 0x03, 0x02, 0x04, 0x03, 0x05, 0x05, 0x04, 0x04,
  0x00, 0x00, 0x01, 0x7D,
  // AC0 symbol definitions
  0x01, 0x02, 0x03, 0x00, 0x04, 0x11, 0x05, 0x12, 0x21, 0x31, 0x41, 0x06,
  0x13, 0x51, 0x61, 0x07,
  0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xA1, 0x08, 0x23, 0x42, 0xB1, 0xC1,
  0x15, 0x52, 0xD1, 0xF0,
  0x24, 0x33, 0x62, 0x72, 0x82, 0x09, 0x0A, 0x16, 0x17, 0x18, 0x19, 0x1A,
  0x25, 0x26, 0x27, 0x28,
  0x29, 0x2A, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x43, 0x44, 0x45,
  0x46, 0x47, 0x48, 0x49,
  0x4A, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x63, 0x64, 0x65,
  0x66, 0x67, 0x68, 0x69,
  0x6A, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x83, 0x84, 0x85,
  0x86, 0x87, 0x88, 0x89,
  0x8A, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9A, 0xA2, 0xA3,
  0xA4, 0xA5, 0xA6, 0xA7,
  0xA8, 0xA9, 0xAA, 0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0xB7, 0xB8, 0xB9, 0xBA,
  0xC2, 0xC3, 0xC4, 0xC5,
  0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6, 0xD7, 0xD8,
  0xD9, 0xDA, 0xE1, 0xE2,
  0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xF1, 0xF2, 0xF3, 0xF4,
  0xF5, 0xF6, 0xF7, 0xF8,
  0xF9, 0xFA,

  0x11,
  // AC1 length specifications
  0x00, 0x02, 0x01, 0x02, 0x04, 0x04, 0x03, 0x04, 0x07, 0x05, 0x04, 0x04,
  0x00, 0x01, 0x02, 0x77,
  // AC1 symbol definitions
  0x00, 0x01, 0x02, 0x03, 0x11, 0x04, 0x05, 0x21, 0x31, 0x06, 0x12, 0x41,
  0x51, 0x07, 0x61, 0x71,
  0x13, 0x22, 0x32, 0x81, 0x08, 0x14, 0x42, 0x91, 0xA1, 0xB1, 0xC1, 0x09,
  0x23, 0x33, 0x52, 0xF0,
  0x15, 0x62, 0x72, 0xD1, 0x0A, 0x16, 0x24, 0x34, 0xE1, 0x25, 0xF1, 0x17,
  0x18, 0x19, 0x1A, 0x26,
  0x27, 0x28, 0x29, 0x2A, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x43, 0x44,
  0x45, 0x46, 0x47, 0x48,
  0x49, 0x4A, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x63, 0x64,
  0x65, 0x66, 0x67, 0x68,
  0x69, 0x6A, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x82, 0x83,
  0x84, 0x85, 0x86, 0x87,
  0x88, 0x89, 0x8A, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9A,
  0xA2, 0xA3, 0xA4, 0xA5,
  0xA6, 0xA7, 0xA8, 0xA9, 0xAA, 0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0xB7, 0xB8,
  0xB9, 0xBA, 0xC2, 0xC3,
  0xC4, 0xC5, 0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6,
  0xD7, 0xD8, 0xD9, 0xDA,
  0xE2, 0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xF2, 0xF3, 0xF4,
  0xF5, 0xF6, 0xF7, 0xF8,
  0xF9, 0xFA,

  0x00, 0x00, 0x00, 0x00,	// unused
  0x00, 0x00, 0x00, 0x00,

  0xff,				// APP_H
  0xe0,				// APP_L
  0x00,				// LEN_H
  0x10,				// LEN_L
  0x4a, 0x46, 0x49, 0x46,	// APP segment
  0x00, 0x01, 0x01, 0x01,
  0x01, 0x2c, 0x01, 0x2c,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0xff,				// COM_H
  0xfe,				// COM_L
  0x00,				// LEN_H
  0x3e,				// LEN_L
  0x00, 0x00, 0x00, 0x00,	// COM segment
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00
};



BYTE                      REGS_D_NTSC[23][2] = {	//Register        Value                 *=NTSC/PAL              #=tinker?
  {0x01, 0x08},			//Hor incr delay, recommended
  {0x02, 0xc0},			//analog input ctrl 1
  {0x03, 0x33},			//analog ctrl 2
  {0x04, 0x00},			//analog ctrl 3
  {0x05, 0x00},			//analog ctrl 4
  {0x06, 0xe9},			//hor sync start
  {0x07, 0x0d},			//hor sync stop
  {0x08, 0x79},			//sync ctrl                     *       0xf8
  {0x09, 0x40},			//luminance ctrl                                                                #0x50
  {0x0a, 0x80},			//luminance brightness
  {0x0b, 0x47},			//luminance contrast
  {0x0c, 0x40},			//chrominance saturation
  {0x0d, 0x00},			//chrominance hue
  {0x0e, 0x00},			//chrominance ctrl                                                              #0x01
  {0x0f, 0x24},			//chromonance gain                                                              #
  {0x10, 0x00},			//format/delay ctrl
  {0x11, 0x0c},			//out ctrl 1
  {0x12, 0xf9},			//out ctrl 2:RTS0=HQ,RTS1=FID
  {0x13, 0x00},			//out ctrl 3
  {0x14, 0x00},			//reserved
  {0x15, 0x10},			//FID polarity change                                                   #
  {0x16, 0x08},			//VGATE stop
  {0x17, 0x00}			//VGATE MSB's
};

BYTE                      REGS_D_PAL[23][2] = {	//Register        Value                 *=NTSC/PAL              #=tinker?
  {0x01, 0x08},			//Hor incr delay, recommended
  {0x02, 0xc0},			//analog input ctrl 1
  {0x03, 0x33},			//analog ctrl 2
  {0x04, 0x00},			//analog ctrl 3
  {0x05, 0x00},			//analog ctrl 4
  {0x06, 0xe9},			//hor sync start
  {0x07, 0x0d},			//hor sync stop
  {0x08, 0x39},			//sync ctrl                     *
  {0x09, 0x50},			//luminance ctrl                                                                #0x52
  {0x0a, 0x80},			//luminance brightness
  {0x0b, 0x47},			//luminance contrast
  {0x0c, 0x40},			//chrominance saturation
  {0x0d, 0x00},			//chrominance hue
  {0x0e, 0x01},			//chrominance ctrl                                                              #0x01
  {0x0f, 0x24},			//chromonance gain                                                              #
  {0x10, 0x00},			//format/delay ctrl
  {0x11, 0x0c},			//out ctrl 1
  {0x12, 0xf9},			//out ctrl 2:RTS0=HQ,RTS1=FID
  {0x13, 0x00},			//out ctrl 3
  {0x14, 0x00},			//reserved
  {0x15, 0x10},			//FID polarity change                                                   #
  {0x16, 0x08},			//VGATE stop
  {0x17, 0x00}			//VGATE MSB's
};

BYTE                      fnt[256][16] =	// 8 x 16 sans serife font- each line represents one character.
{
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7e, 0x81, 0xa5, 0x81, 0x81, 0xbd, 0x99, 0x81, 0x81, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7e, 0xff, 0xdb, 0xff, 0xff, 0xc3, 0xe7, 0xff, 0xff, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x6c, 0xfe, 0xfe, 0xfe, 0xfe, 0x7c, 0x38, 0x10,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x10, 0x38, 0x7c, 0xfe, 0x7c, 0x38, 0x10, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x18, 0x3c, 0x3c, 0xe7, 0xe7, 0xe7, 0x18, 0x18, 0x3c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x18, 0x3c, 0x7e, 0xff, 0xff, 0x7e, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x3c, 0x3c, 0x18, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xc3, 0xc3, 0xe7, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x66, 0x42, 0x42, 0x66, 0x3c, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0xff, 0xff, 0xff, 0xff, 0xff, 0xc3, 0x99, 0xbd, 0xbd, 0x99, 0xc3, 0xff,
   0xff, 0xff, 0xff, 0xff},
  {0x00, 0x00, 0x1e, 0x0e, 0x1a, 0x32, 0x78, 0xcc, 0xcc, 0xcc, 0xcc, 0x78,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3c, 0x66, 0x66, 0x66, 0x66, 0x3c, 0x18, 0x7e, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3f, 0x33, 0x3f, 0x30, 0x30, 0x30, 0x30, 0x70, 0xf0, 0xe0,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7f, 0x63, 0x7f, 0x63, 0x63, 0x63, 0x63, 0x67, 0xe7, 0xe6,
   0xc0, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x18, 0x18, 0xdb, 0x3c, 0xe7, 0x3c, 0xdb, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x80, 0xc0, 0xe0, 0xf0, 0xf8, 0xfe, 0xf8, 0xf0, 0xe0, 0xc0, 0x80,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x02, 0x06, 0x0e, 0x1e, 0x3e, 0xfe, 0x3e, 0x1e, 0x0e, 0x06, 0x02,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x3c, 0x7e, 0x18, 0x18, 0x18, 0x7e, 0x3c, 0x18, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x00, 0x66, 0x66,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7f, 0xdb, 0xdb, 0xdb, 0x7b, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x7c, 0xc6, 0x60, 0x38, 0x6c, 0xc6, 0xc6, 0x6c, 0x38, 0x0c, 0xc6,
   0x7c, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xfe, 0xfe, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x3c, 0x7e, 0x18, 0x18, 0x18, 0x7e, 0x3c, 0x18, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x3c, 0x7e, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x7e, 0x3c, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x0c, 0xfe, 0x0c, 0x18, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x60, 0xfe, 0x60, 0x30, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xc0, 0xc0, 0xfe, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x24, 0x66, 0xff, 0x66, 0x24, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x10, 0x38, 0x38, 0x7c, 0x7c, 0xfe, 0xfe, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0xfe, 0xfe, 0x7c, 0x7c, 0x38, 0x38, 0x10, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x3c, 0x3c, 0x3c, 0x18, 0x18, 0x18, 0x00, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x66, 0x66, 0x66, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x6c, 0x6c, 0xfe, 0x6c, 0x6c, 0x6c, 0xfe, 0x6c, 0x6c,
   0x00, 0x00, 0x00, 0x00},
  {0x18, 0x18, 0x7c, 0xc6, 0xc2, 0xc0, 0x7c, 0x06, 0x06, 0x86, 0xc6, 0x7c,
   0x18, 0x18, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0xc2, 0xc6, 0x0c, 0x18, 0x30, 0x60, 0xc6, 0x86,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x38, 0x6c, 0x6c, 0x38, 0x76, 0xdc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x30, 0x30, 0x30, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x0c, 0x18, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x18, 0x0c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x30, 0x18, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x18, 0x30,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x66, 0x3c, 0xff, 0x3c, 0x66, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x7e, 0x18, 0x18, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x18,
   0x30, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x02, 0x06, 0x0c, 0x18, 0x30, 0x60, 0xc0, 0x80,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xce, 0xde, 0xf6, 0xe6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x38, 0x78, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0x06, 0x0c, 0x18, 0x30, 0x60, 0xc0, 0xc6, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0x06, 0x06, 0x3c, 0x06, 0x06, 0x06, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x0c, 0x1c, 0x3c, 0x6c, 0xcc, 0xfe, 0x0c, 0x0c, 0x0c, 0x0c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xfe, 0xc0, 0xc0, 0xc0, 0xfc, 0x06, 0x06, 0x06, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x38, 0x60, 0xc0, 0xc0, 0xfc, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xfe, 0xc6, 0x06, 0x06, 0x0c, 0x18, 0x30, 0x30, 0x30, 0x30,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0x7e, 0x06, 0x06, 0x06, 0x0c, 0x78,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x00, 0x00, 0x00, 0x18, 0x18, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x00, 0x00, 0x00, 0x18, 0x18, 0x30,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x06, 0x0c, 0x18, 0x30, 0x60, 0x30, 0x18, 0x0c, 0x06,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x60, 0x30, 0x18, 0x0c, 0x06, 0x0c, 0x18, 0x30, 0x60,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0x0c, 0x18, 0x18, 0x18, 0x00, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xde, 0xd6, 0xd6, 0xdc, 0xc0, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x38, 0x6c, 0xc6, 0xc6, 0xc6, 0xfe, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xfc, 0xc6, 0xc6, 0xc6, 0xfc, 0xc6, 0xc6, 0xc6, 0xc6, 0xfc,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3c, 0x66, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0x66, 0x3c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xf8, 0xcc, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xcc, 0xf8,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xfe, 0xc0, 0xc0, 0xc0, 0xf8, 0xc0, 0xc0, 0xc0, 0xc0, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xfe, 0xc0, 0xc0, 0xc0, 0xf8, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3c, 0x66, 0xc2, 0xc0, 0xc0, 0xde, 0xc6, 0xc6, 0x66, 0x3c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0xc6, 0xc6, 0xc6, 0xfe, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7e, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0xcc, 0xcc, 0xcc, 0x78,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0xc6, 0xcc, 0xd8, 0xf0, 0xf0, 0xd8, 0xcc, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc3, 0xe7, 0xff, 0xff, 0xdb, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0xe6, 0xf6, 0xfe, 0xde, 0xce, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xfc, 0xc6, 0xc6, 0xc6, 0xfc, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xd6, 0xde, 0x7c,
   0x0e, 0x02, 0x00, 0x00},
  {0x00, 0x00, 0xfc, 0xc6, 0xc6, 0xc6, 0xfc, 0xcc, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x7c, 0xc6, 0xc6, 0x60, 0x38, 0x0c, 0x06, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xff, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0x66, 0x3c, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc3, 0xc3, 0xc3, 0xc3, 0xc3, 0xdb, 0xdb, 0xff, 0x66, 0x66,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc3, 0xc3, 0x66, 0x3c, 0x18, 0x18, 0x3c, 0x66, 0xc3, 0xc3,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc3, 0xc3, 0xc3, 0x66, 0x3c, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xff, 0x03, 0x06, 0x0c, 0x18, 0x30, 0x60, 0xc0, 0xc0, 0xff,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3c, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x3c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x80, 0xc0, 0xe0, 0x70, 0x38, 0x1c, 0x0e, 0x06, 0x02,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x3c,
   0x00, 0x00, 0x00, 0x00},
  {0x10, 0x38, 0x6c, 0xc6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0xff, 0x00, 0x00},
  {0x30, 0x30, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x0c, 0x7c, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc0, 0xc0, 0xc0, 0xfc, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xfc,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0xc6, 0xc0, 0xc0, 0xc0, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x0c, 0x0c, 0x0c, 0x3c, 0x6c, 0xcc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xfc, 0xc0, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x38, 0x6c, 0x64, 0x60, 0xf0, 0x60, 0x60, 0x60, 0x60, 0x60,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x76, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x7c,
   0x0c, 0xcc, 0x78, 0x00},
  {0x00, 0x00, 0xc0, 0xc0, 0xc0, 0xdc, 0xf6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x18, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x06, 0x06, 0x00, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06,
   0x66, 0x66, 0x3c, 0x00},
  {0x00, 0x00, 0xc0, 0xc0, 0xc0, 0xc6, 0xcc, 0xf8, 0xf8, 0xcc, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xff, 0xdb, 0xdb, 0xdb, 0xdb, 0xdb,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0xe6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0xe6, 0xc6, 0xc6, 0xc6, 0xc6, 0xfc,
   0xc0, 0xc0, 0xc0, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x72, 0xce, 0xc6, 0xc6, 0xc6, 0xc6, 0x7e,
   0x06, 0x06, 0x06, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0xf6, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0xc6, 0x60, 0x38, 0x0c, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x10, 0x30, 0x30, 0xfc, 0x30, 0x30, 0x30, 0x30, 0x36, 0x1c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xc3, 0xc3, 0xc3, 0xc3, 0x66, 0x3c, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xc3, 0xc3, 0xc3, 0xdb, 0xdb, 0xff, 0x66,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xc3, 0x66, 0x3c, 0x18, 0x3c, 0x66, 0xc3,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7e,
   0x06, 0x0c, 0xf8, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x0c, 0x18, 0x30, 0x60, 0xc0, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x0e, 0x18, 0x18, 0x18, 0x70, 0x18, 0x18, 0x18, 0x18, 0x0e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x18, 0x18, 0x18, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x70, 0x18, 0x18, 0x18, 0x0e, 0x18, 0x18, 0x18, 0x18, 0x70,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x76, 0xdc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x10, 0x38, 0x6c, 0xc6, 0xc6, 0xc6, 0xfe, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3c, 0x66, 0xc2, 0xc0, 0xc0, 0xc0, 0xc2, 0x66, 0x3c, 0x0c,
   0x06, 0x7c, 0x00, 0x00},
  {0x00, 0x00, 0xcc, 0x00, 0x00, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x0c, 0x18, 0x30, 0x00, 0x7c, 0xc6, 0xc6, 0xfc, 0xc0, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x10, 0x38, 0x6c, 0x00, 0x78, 0x0c, 0x7c, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xcc, 0x00, 0x00, 0x78, 0x0c, 0x7c, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x60, 0x30, 0x18, 0x00, 0x78, 0x0c, 0x7c, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x38, 0x6c, 0x38, 0x00, 0x78, 0x0c, 0x7c, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x3c, 0x66, 0x60, 0x60, 0x66, 0x3c, 0x0c, 0x06,
   0x3c, 0x00, 0x00, 0x00},
  {0x00, 0x10, 0x38, 0x6c, 0x00, 0x7c, 0xc6, 0xc6, 0xfc, 0xc0, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xfc, 0xc0, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x60, 0x30, 0x18, 0x00, 0x7c, 0xc6, 0xc6, 0xfc, 0xc0, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x66, 0x00, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x18, 0x3c, 0x66, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x60, 0x30, 0x18, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0xc6, 0x00, 0x38, 0x6c, 0xc6, 0xc6, 0xc6, 0xfe, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x38, 0x6c, 0x38, 0x00, 0x38, 0x6c, 0xc6, 0xc6, 0xfe, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x18, 0x30, 0x60, 0x00, 0xfe, 0xc0, 0xc0, 0xfc, 0xc0, 0xc0, 0xc0, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x3b, 0x1b, 0x7e, 0xd8, 0xdc, 0x77,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x3e, 0x6c, 0xcc, 0xcc, 0xfe, 0xcc, 0xcc, 0xcc, 0xcc, 0xce,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x10, 0x38, 0x6c, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x60, 0x30, 0x18, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x30, 0x78, 0xcc, 0x00, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x60, 0x30, 0x18, 0x00, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc6, 0x00, 0x00, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7e,
   0x06, 0x0c, 0xf8, 0x00},
  {0x00, 0xc6, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0xc6, 0x00, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x18, 0x18, 0x7e, 0xc3, 0xc0, 0xc0, 0xc0, 0xc3, 0x7e, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x38, 0x6c, 0x64, 0x60, 0x60, 0xf8, 0x60, 0x60, 0x60, 0x60, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0xc3, 0x66, 0x3c, 0x18, 0xff, 0x18, 0xff, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0xfc, 0x66, 0x66, 0x7c, 0x62, 0x66, 0x6f, 0x66, 0x66, 0x66, 0xf3,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x0e, 0x1b, 0x18, 0x18, 0x18, 0x7e, 0x18, 0x18, 0x18, 0x18, 0x18,
   0xd8, 0x70, 0x00, 0x00},
  {0x00, 0x18, 0x30, 0x60, 0x00, 0x78, 0x0c, 0x7c, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x0c, 0x18, 0x30, 0x00, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x18, 0x30, 0x60, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x18, 0x30, 0x60, 0x00, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x76, 0xdc, 0x00, 0xdc, 0xe6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x76, 0xdc, 0x00, 0xc6, 0xe6, 0xf6, 0xfe, 0xde, 0xce, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x3c, 0x6c, 0x6c, 0x3e, 0x00, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x38, 0x6c, 0x6c, 0x38, 0x00, 0x7c, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x30, 0x30, 0x00, 0x30, 0x30, 0x60, 0xc0, 0xc6, 0xc6, 0x7c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xc0, 0xc0, 0xc0, 0xc0, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x06, 0x06, 0x06, 0x06, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0xc0, 0xc0, 0xc2, 0xc6, 0xcc, 0x18, 0x30, 0x60, 0xce, 0x9b, 0x06,
   0x0c, 0x1f, 0x00, 0x00},
  {0x00, 0xc0, 0xc0, 0xc2, 0xc6, 0xcc, 0x18, 0x30, 0x66, 0xce, 0x96, 0x3e,
   0x06, 0x06, 0x00, 0x00},
  {0x00, 0x00, 0x18, 0x18, 0x00, 0x18, 0x18, 0x18, 0x3c, 0x3c, 0x3c, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x36, 0x6c, 0xd8, 0x6c, 0x36, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xd8, 0x6c, 0x36, 0x6c, 0xd8, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x11, 0x44, 0x11, 0x44, 0x11, 0x44, 0x11, 0x44, 0x11, 0x44, 0x11, 0x44,
   0x11, 0x44, 0x11, 0x44},
  {0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa,
   0x55, 0xaa, 0x55, 0xaa},
  {0xdd, 0x77, 0xdd, 0x77, 0xdd, 0x77, 0xdd, 0x77, 0xdd, 0x77, 0xdd, 0x77,
   0xdd, 0x77, 0xdd, 0x77},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0xf8, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0xf8, 0x18, 0xf8, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xf6, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x18, 0xf8, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0xf6, 0x06, 0xf6, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x06, 0xf6, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0xf6, 0x06, 0xfe, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xfe, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0xf8, 0x18, 0xf8, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x1f, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0xff, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x1f, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0xff, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x1f, 0x18, 0x1f, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x37, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x37, 0x30, 0x3f, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x30, 0x37, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0xf7, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0xf7, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x37, 0x30, 0x37, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0xf7, 0x00, 0xf7, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0xff, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xff, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0xff, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x3f, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x1f, 0x18, 0x1f, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0x18, 0x1f, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xff, 0x36, 0x36, 0x36, 0x36,
   0x36, 0x36, 0x36, 0x36},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0xff, 0x18, 0xff, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0xf8, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff},
  {0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0, 0xf0,
   0xf0, 0xf0, 0xf0, 0xf0},
  {0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f, 0x0f,
   0x0f, 0x0f, 0x0f, 0x0f},
  {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x76, 0xde, 0xcc, 0xcc, 0xcc, 0xde, 0x76,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x78, 0xcc, 0xcc, 0xcc, 0xf8, 0xcc, 0xc6, 0xc6, 0xc6, 0xfc,
   0xc0, 0xc0, 0xc0, 0x00},
  {0x00, 0x00, 0xfe, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0, 0xc0,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x6c, 0x6c, 0x6c, 0x6c, 0x6c, 0x6c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0xfe, 0xc6, 0x60, 0x30, 0x18, 0x30, 0x60, 0xc6, 0xfe,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc, 0x78,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x66, 0x66, 0x66, 0x66, 0x7c, 0x60, 0x60,
   0x60, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x76, 0xdc, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x7e, 0x18, 0x3c, 0x66, 0x66, 0x66, 0x3c, 0x18, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x38, 0x6c, 0xc6, 0xc6, 0xfe, 0xc6, 0xc6, 0x6c, 0x38,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x38, 0x6c, 0xc6, 0xc6, 0xc6, 0x6c, 0x6c, 0x6c, 0x6c, 0xee,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x1e, 0x30, 0x18, 0x0c, 0x3e, 0x66, 0x66, 0x66, 0x66, 0x3c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xdb, 0xdb, 0xdb, 0x7e, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x03, 0x06, 0x7e, 0xdb, 0xdb, 0xf3, 0x7e, 0x60, 0xc0,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x1c, 0x30, 0x60, 0x60, 0x7c, 0x60, 0x60, 0x60, 0x30, 0x1c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x7c, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 0x00, 0xfe, 0x00, 0x00, 0xfe, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x7e, 0x18, 0x18, 0x00, 0x00, 0xff,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x30, 0x18, 0x0c, 0x06, 0x0c, 0x18, 0x30, 0x00, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x0c, 0x18, 0x30, 0x60, 0x30, 0x18, 0x0c, 0x00, 0x7e,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x0e, 0x1b, 0x1b, 0x1b, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18,
   0x18, 0x18, 0x18, 0x18},
  {0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0xd8, 0xd8, 0xd8, 0x70,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x00, 0x7e, 0x00, 0x18, 0x18, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x76, 0xdc, 0x00, 0x76, 0xdc, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x38, 0x6c, 0x6c, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x18, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x0f, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0xec, 0x6c, 0x6c, 0x3c, 0x1c,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0xd8, 0x6c, 0x6c, 0x6c, 0x6c, 0x6c, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x70, 0xd8, 0x30, 0x60, 0xc0, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x7c, 0x7c, 0x7c, 0x7c, 0x7c, 0x7c, 0x7c, 0x00,
   0x00, 0x00, 0x00, 0x00},
  {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00},
};

struct pagelist
{
  unsigned long physicaladdress;
  struct pagelist *pnextpage;

};
 
typedef struct
{
  BYTE busy;
  BYTE complete;
  BYTE read;
  DWORD ptbmpphys;//bitmap page table start phys address;
  DWORD ptjpgphys;//jpeg page table start phys address;
  DWORD ptbmpuser;//bitmap page table start user address;
  DWORD ptjpguser;//jpeg page table start user address;
  DWORD rpsbmpphys;//bitmap RPS prog start phys address;
  DWORD rpsbmpuser;//bmpg RPS prog start user address;
  DWORD rpsjpgphys;//jpeg RPS prog start phys address;
  DWORD rpsjpguser;//jpeg RPS prog start user address;
  DWORD jpegbufferuser;
  DWORD jpegbufferphys;
  DWORD bmpbufferuser;
  DWORD bmpbufferphys;
  DWORD                     jpegsize;	//      actual size of jpeg data;
  LPBITMAPINFO              lpbmi;	//      pointer to BITMAPINFO structure;
  struct timeval            timestamp;	//      timestamp structure;
  int                       videopresent;	//   video present flag;
  int                       xpchan;	//      one of 16 crosspoint switch channels (1-16) captured from;
  int                       camera;   //1..16 camera used
  int                       channel;  //0..3 decoder

}bufinfo;

typedef struct
{
  int                       jpegon;	//JPEG capture ON/OFF
  int                       captionmode; // caption mode for current capture: ON/OFF, caption color;
  int                       interlacemode;// interlaced, line doubling, line interpolation
  DWORD                     bqfull;	//  buffer queue full (cumulative); overrun
  DWORD                     incomplete;	//      compression incomplete (cumulative);
  DWORD                     zerror;	//      compression error (cumulative);
  unsigned char             SEQUENCE[SEQ_MAX][2];  // SEQUENCE[n][0] = channel(0-3)  
                                                  // SEQUENCE[n][1] = port(1-16)
}status;

typedef struct
{
  struct pci_dev *pdev;
  void* base;
  wait_queue_head_t wait_queue;
  int wait_condition;
  BYTE busy;
  BYTE dointerrupts;
  volatile DWORD interruptcounter;
  volatile DWORD interruptslost;
  char name[10];
  DWORD                     xpdata;	//current crosspoint switch state;
  DWORD                     captionformat;	//current caption window format;
  MODE                      mode;
  struct pagelist           *ppagelist;
  bufinfo                   bufferinfo[SYS_BUFFERS];
  status                    cardstatus;
  int                       myminor;
  int                       sequenceposition;
  BUFFER*                   pbuffer[SYS_BUFFERS];
}
cardinfo;


#endif
